@@ -1,10 +1,10 @@
-from django.conf import settings
 from django.http import HttpResponsePermanentRedirect
 from django.utils.decorators import available_attrs
+from django.conf import settings
+from django.utils.functional import wraps
 
 from userena import settings as userena_settings
 
-from django.utils.functional import wraps
 
 def secure_required(view_func):
     """
@@ -21,7 +21,7 @@ def secure_required(view_func):
     """
     def _wrapped_view(request, *args, **kwargs):
         if not request.is_secure():
-            if userena_settings.USERENA_USE_HTTPS:
+            if getattr(settings, 'USERENA_USE_HTTPS', userena_settings.DEFAULT_USERENA_USE_HTTPS):
                 request_url = request.build_absolute_uri(request.get_full_path())
                 secure_url = request_url.replace('http://', 'https://')
                 return HttpResponsePermanentRedirect(secure_url)
