@@ -2,12 +2,9 @@ from django.core.urlresolvers import reverse
 from django.shortcuts import redirect, get_object_or_404
 from django.contrib.auth import authenticate, login, logout, REDIRECT_FIELD_NAME
 from django.contrib.auth.forms import PasswordChangeForm
-from django.contrib.auth.decorators import login_required
 from django.contrib.auth.views import logout as Signout
 from django.views.generic import TemplateView
-from django.template.context import RequestContext
 from django.views.generic.list import ListView
-from django.conf import settings
 from django.contrib import messages
 from django.core.exceptions import PermissionDenied
 from django.utils.translation import ugettext as _
@@ -17,8 +14,8 @@ from userena.forms import (SignupForm, SignupFormOnlyEmail, AuthenticationForm,
                            ChangeEmailForm, EditProfileForm)
 from userena.models import UserenaSignup
 from userena.decorators import secure_required
-from userena.backends import UserenaAuthenticationBackend
-from userena.utils import signin_redirect, get_profile_model, get_user_model
+from userena.utils import (signin_redirect, get_profile_model, get_user_model,
+                           get_user_profile)
 from userena import signals as userena_signals
 from userena import settings as userena_settings
 
@@ -162,7 +159,7 @@ def activate(request, activation_key,
     ``success_url``.  If the SHA1 is not found, the user will be shown the
     ``template_name`` template displaying a fail message.
     If the SHA1 is found but expired, ``retry_template_name`` is used instead,
-    so the user can proceed to :func:`activate_retry` to get a new actvation key.
+    so the user can proceed to :func:`activate_retry` to get a new activation key.
 
     :param activation_key:
         String of a SHA1 string of 40 characters long. A SHA1 is always 160bit
@@ -347,7 +344,7 @@ def direct_to_user_template(request, username, template_name,
 
     if not extra_context: extra_context = dict()
     extra_context['viewed_user'] = user
-    extra_context['profile'] = user.get_profile()
+    extra_context['profile'] = get_user_profile(user=user)
     return ExtraContextTemplateView.as_view(template_name=template_name,
                                             extra_context=extra_context)(request)
 
@@ -376,7 +373,7 @@ def disabled_account(request, username, template_name, extra_context=None):
 
     ``profile``
         Profile of the viewed user.
-    
+
     """
     user = get_object_or_404(get_user_model(), username__iexact=username)
 
@@ -385,10 +382,10 @@ def disabled_account(request, username, template_name, extra_context=None):
 
     if not extra_context: extra_context = dict()
     extra_context['viewed_user'] = user
-    extra_context['profile'] = user.get_profile()
+    extra_context['profile'] = get_user_profile(user=user)
     return ExtraContextTemplateView.as_view(template_name=template_name,
                                             extra_context=extra_context)(request)
-    
+
 @secure_required
 def signin(request, auth_form=AuthenticationForm,
            template_name='userena/signin_form.html',
@@ -542,9 +539,7 @@ def email_change(request, username, email_form=ChangeEmailForm,
     form = email_form(user)
 
     if request.method == 'POST':
-        form = email_form(user,
-                               request.POST,
-                               request.FILES)
+        form = email_form(user, request.POST, request.FILES)
 
         if form.is_valid():
             form.save()
@@ -562,7 +557,7 @@ def email_change(request, username, email_form=ChangeEmailForm,
 
     if not extra_context: extra_context = dict()
     extra_context['form'] = form
-    extra_context['profile'] = user.get_profile()
+    extra_context['profile'] = get_user_profile(user=user)
     return ExtraContextTemplateView.as_view(template_name=template_name,
                                             extra_context=extra_context)(request)
 
@@ -627,7 +622,7 @@ def password_change(request, username, template_name='userena/password_form.html
 
     if not extra_context: extra_context = dict()
     extra_context['form'] = form
-    extra_context['profile'] = user.get_profile()
+    extra_context['profile'] = get_user_profile(user=user)
     return ExtraContextTemplateView.as_view(template_name=template_name,
                                             extra_context=extra_context)(request)
 @secure_required
@@ -676,10 +671,9 @@ def profile_edit(request, username, edit_profile_form=EditProfileForm,
         Instance of the ``Profile`` that is edited.
 
     """
-    user = get_object_or_404(get_user_model(),
-                             username__iexact=username)
+    user = get_object_or_404(get_user_model(), username__iexact=username)
 
-    profile = user.get_profile()
+    profile = get_user_profile(user=user)
 
     user_initial = {'first_name': user.first_name,
                     'last_name': user.last_name}
@@ -733,19 +727,12 @@ def profile_detail(request, username,
         Instance of the currently viewed ``Profile``.
 
     """
-    user = get_object_or_404(get_user_model(),
-                             username__iexact=username)
-
-    profile_model = get_profile_model()
-    try:
-        profile = user.get_profile()
-    except profile_model.DoesNotExist:
-        profile = profile_model.objects.create(user=user)
-
+    user = get_object_or_404(get_user_model(), username__iexact=username)
+    profile = get_user_profile(user=user)
     if not profile.can_view_profile(request.user):
         raise PermissionDenied
     if not extra_context: extra_context = dict()
-    extra_context['profile'] = user.get_profile()
+    extra_context['profile'] = profile
     extra_context['hide_email'] = userena_settings.USERENA_HIDE_EMAIL
     return ExtraContextTemplateView.as_view(template_name=template_name,
                                             extra_context=extra_context)(request)
